@@ -16,8 +16,9 @@ use List::Util qw(first);
 use namespace::autoclean;
 
 extends 'App::Sqitch::Command';
+with 'App::Sqitch::Role::ContextCommand';
 
-our $VERSION = '0.9998';
+our $VERSION = '0.9999';
 
 has change_name => (
     is  => 'ro',
@@ -115,14 +116,6 @@ sub _config_templates {
     my ($self, $config) = @_;
     my $tmpl = $config->get_section( section => 'add.templates' );
     $_ = _check_script $_ for values %{ $tmpl };
-
-    # Get legacy config.
-    for my $script (qw(deploy revert verify)) {
-        next if $tmpl->{$script};
-        if (my $file = $config->get( key => "add.$script\_template")) {
-            $tmpl->{$script} = _check_script $file;
-        }
-    }
     return $tmpl;
 }
 
@@ -171,21 +164,12 @@ sub options {
         without=s@
         use=s%
         open-editor|edit|e!
-
-        deploy-template=s
-        revert-template=s
-        verify-template=s
-        deploy!
-        revert!
-        verify!
     );
-    # Those last six are deprecated.
 }
 
 # Override to convert multiple vars to an array.
 sub _parse_opts {
     my ( $class, $args ) = @_;
-    return {} unless $args && @{$args};
 
     my (%opts, %vars);
     Getopt::Long::Configure(qw(bundling no_pass_through));
@@ -212,34 +196,10 @@ sub _parse_opts {
 
     # Merge with and without.
     $opts{with_scripts} = {
-        ( map {
-            if (exists $opts{$_}) {
-                App::Sqitch->warn(__x(
-                    'Option --{opt} has been deprecated; use "--{with} {val}" instead',
-                    opt  => $_,
-                    with => $opts{$_} ? 'with' : 'without',
-                    val  => $_
-                ));
-            }
-            $_ => delete $opts{$_} // 1;
-        } qw(deploy revert verify) ),
+        ( map { $_ => 1 } qw(deploy revert verify) ),
         ( map { $_ => 1 } @{ delete $opts{with}    || [] } ),
         ( map { $_ => 0 } @{ delete $opts{without} || [] } ),
     };
-
-    # Merge deprecated use options.
-    for my $script (qw(deploy revert verify)) {
-        next unless exists $opts{"$script\_template"};
-        $opts{use} ||= {};
-        $opts{use}{$script} = delete $opts{"$script\_template"};
-        App::Sqitch->warn(__x(
-            'Option --{opt} has been deprecated; use "--use {key}={val}" instead',
-            opt => "$script-template",
-            key => $script,
-            val => $opts{use}{$script},
-        ));
-    }
-
     return \%opts;
 }
 
@@ -306,11 +266,12 @@ sub configure {
 
 sub execute {
     my $self = shift;
+    $self->usage unless @_ || $self->change_name;
+
     my ($name, $targets) = $self->parse_args(
         names      => [$self->change_name],
         all        => $self->all,
         args       => \@_,
-        no_default => 1,
         no_changes => 1,
     );
 
